@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: setup.py 10314 2017-09-24 09:37:54Z Lavender $
+# $Id: setup.py 10318 2017-09-26 06:38:48Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-09-24 17:37:54 +0800 (週日, 24 九月 2017) $
-# $Revision: 10314 $ 
+# $Date: 2017-09-26 14:38:48 +0800 (週二, 26 九月 2017) $
+# $Revision: 10318 $ 
 
 import os
 import sys
@@ -21,12 +21,6 @@ import logging
 import shutil
 import argparse
 
-import django
-
-from django.db import transaction
-
-SETUP_DIR = os.path.dirname(os.path.abspath(__file__))
-
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.DEBUG)
 handler = logging.StreamHandler()
@@ -34,6 +28,8 @@ handler.setFormatter(
     logging.Formatter("%(asctime)s - %(levelname)s - %(message)s"))
 logger.addHandler(handler)
 
+SETUP_DIR = os.path.dirname(os.path.abspath(__file__))
+
 def copyToPath(baseDir, templateDir, staticDir, mode):
     if not templateDir:
         templateDir = os.path.join(baseDir, 'templates')
@@ -83,7 +79,7 @@ def copyToPath(baseDir, templateDir, staticDir, mode):
                 continue
             
             if os.path.isfile(dst):
-                logger.error("%s is exist. failed to copy file." % dst)
+                logger.error("%s exists. failed to copy file." % dst)
             else:
                 shutil.copyfile(origin, dst)
                 logger.info("Succeed to copy file to %s." % dst)
@@ -120,7 +116,7 @@ def writeSettings(settingsPath, templateDir, staticDir, hasCmsTemplate):
     settingsDir = os.path.dirname(settingsPath)
     bak = os.path.join(settingsDir, 'settings.py.bak')
     if os.path.isfile(bak):
-        logger.error("%s is exist. failed to backup file." % bak)
+        logger.error("%s exists. failed to backup file." % bak)
         return 
     shutil.copyfile(settingsPath, bak)
     logger.info("Succeed to backup settings.py to %s." % bak)
@@ -158,8 +154,7 @@ else:
         
         settings.write(content)
     logger.info("Succeed to write settings.py")
-              
-@transaction.atomic    
+                
 def loadData(baseDir, language):
     logger.info("-----Start load data-----")
     data = os.path.join(".", 'fixtures', 'initial_data.json')
@@ -171,12 +166,16 @@ def loadData(baseDir, language):
     from cms.models.pagemodel import Page
     from cms.models.titlemodels import Title
     from cms.api import copy_plugins_to_language
+    from django.db import transaction
     
-    for page in Page.objects.all():
-        copy_plugins_to_language(page, "zh-hant", language)
-    for title in Title.objects.all():
-        title.language = language
-        title.save()
+    @transaction.atomic
+    def modifyData():
+        for page in Page.objects.all():
+            copy_plugins_to_language(page, "zh-hant", language)
+        for title in Title.objects.all():
+            title.language = language
+            title.save()
+    modifyData()
         
     return True
         
@@ -191,14 +190,14 @@ if __name__ == "__main__":
         help='programmer mode or user mode.')
         
     parser.add_argument(
-        '-q', '--quiet', 
+        '-w', '--wizard', 
         action='store_true',
-        help="Don't run the configuration wizard, "
-             "just use the provided values.")
+        help="Run the configuration wizard")   
+
     
     args = parser.parse_args()
     
-    quiet = args.quiet
+    wizard = args.wizard
 
     if args.mode == 'programmer':
         mode = 'programmer'
@@ -210,13 +209,17 @@ if __name__ == "__main__":
     settingsPath = findSettings(path)
     
     if not settingsPath:
+        try:
+            import djangocms_installer
+        except Exception as e:
+            os.system("pip install djangocms-installer")
         projectName = raw_input(
-            "Django project isn't found. "
+            "Django project not found. "
             "Auto create one by djangocms-installer. Input a project name:")
         path = os.path.join(path, projectName)
         
-        if quiet:
-            result = os.system("djangocms -f -p %s %s -q" % (path, projectName))
+        if wizard:
+            result = os.system("djangocms -f -p %s %s -w" % (path, projectName))
         else:
             result = os.system("djangocms -f -p %s %s" % (path, projectName))
             
@@ -224,7 +227,8 @@ if __name__ == "__main__":
             print
             logger.error(
                 "Please check your environment "
-                "installed djangocms-installer or upgrade to latest.")
+                "which djangocms-installer is installed or "
+                "upgrade to the latest.")
             sys.exit()
             
         settingsPath = findSettings(path)
@@ -237,6 +241,8 @@ if __name__ == "__main__":
     
     sys.path.append(path)
     os.environ['DJANGO_SETTINGS_MODULE'] = settingModule
+    
+    import django
     django.setup()
     
     from django.conf import settings
@@ -244,15 +250,6 @@ if __name__ == "__main__":
     baseDir = settings.BASE_DIR
     
     apps = [
-        'djangocms_admin_style',
-        'django.contrib.auth',
-        'django.contrib.contenttypes',
-        'django.contrib.sessions',
-        'django.contrib.admin',
-        'django.contrib.sites',
-        'django.contrib.sitemaps',
-        'django.contrib.staticfiles',
-        'django.contrib.messages',
         'cms',
         'menus',
         'sekizai',
@@ -260,25 +257,23 @@ if __name__ == "__main__":
         'djangocms_text_ckeditor',
         'filer',
         'easy_thumbnails',
-        'djangocms_column',
-        'djangocms_link',
         'cmsplugin_filer_file',
         'cmsplugin_filer_folder',
         'cmsplugin_filer_image',
-        'cmsplugin_filer_utils',
-        'djangocms_style',
-        'djangocms_snippet',
-        'djangocms_googlemap',
-        'djangocms_video',
     ]
     
     endSetup = False
     for app in apps:
         if not app in settings.INSTALLED_APPS:
-            logger.error("The app doesn't include in INSTALLED_APPS: %s" % app)
+            logger.error("The app doesn't be included in INSTALLED_APPS: %s" % 
+                         app)
             endSetup = True
     
     if endSetup:
+        print
+        logger.error("The project does not support django cms. "
+                     "Please follow the instructions at "
+                     "http://docs.django-cms.org/en/stable/how_to/install.html")
         sys.exit()
             
     try:
@@ -307,5 +302,10 @@ if __name__ == "__main__":
     if not success:
         print
         logger.error("Please check the project's db was migrated.")
+    else:
+        print 
+        logger.info("Get into \"%s\" directory and type"
+                    " \"python manage.py runserver\" to start your project" % 
+                    path)
     
     
\ No newline at end of file
