@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: ThankRedirect.py 9895 2017-04-23 04:33:47Z Lavender $
+# $Id: ThankRedirect.py 9919 2017-04-27 07:05:09Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-04-23 12:33:47 +0800 (週日, 23 四月 2017) $
-# $Revision: 9895 $
+# $Date: 2017-04-27 15:05:09 +0800 (週四, 27 四月 2017) $
+# $Revision: 9919 $
 
 from django import template
 from django.utils.safestring import mark_safe
@@ -21,14 +21,12 @@ from django.conf import settings
 from django.template.loader import get_template
 from django.template import Context
 
-from Zephyrus.landing import getErrorMessage
-
 register = template.Library()
 
 @register.simple_tag
 def ThankRedirect(request):
     fromUrl = request.GET.get('from_url')
-    errorCode = int(request.GET.get('error'))
+    errorCode = int(request.GET.get('error', 0))
     if fromUrl == None:
         return ''
     
@@ -36,14 +34,12 @@ def ThankRedirect(request):
         time = settings.ZEPHYRUS_LANDING_THANK_WAIT_TIME
     else:
         time = 3000
-
+    
     errorHtml = get_template('landing/ErrorMessage.html')
-    errorMessage = getErrorMessage(errorCode)
-    print errorMessage
+    
     errorHtml = errorHtml.render(
-            Context({'errorMessage': errorMessage,})
+            Context({'errorCode': errorCode,})
         )
-    print errorHtml
     
     return mark_safe(
         '''
